Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 6474)
+++ trunk/MagicSoft/Mars/Changelog	(revision 6475)
@@ -31,4 +31,8 @@
      - lowered default low-gain switch from 150 to 120. (for calibration 
        events which saturate more than 5% of the events).
+
+   * mjobs/MJCalib.[h,cc]
+     - include possibility to display pixels distributions for test
+       reasons
 
  2005/02/14 Thomas Bretz
Index: trunk/MagicSoft/Mars/mjobs/MJCalib.cc
===================================================================
--- trunk/MagicSoft/Mars/mjobs/MJCalib.cc	(revision 6474)
+++ trunk/MagicSoft/Mars/mjobs/MJCalib.cc	(revision 6475)
@@ -36,16 +36,29 @@
 using namespace std;
 
+const Int_t MJCalib::fgCheckedPixId = 100;
 // --------------------------------------------------------------------------
 //
 // Default constructor. 
 //
-// Sets fDataFlag to kIsUseRootData
+// Sets:
+// - fDataFlag     to kIsUseRootData
+// - fRuns         to NULL
+// - fCheckedPixId to fgCheckedPixId
+// - fPixelCheck   to kFALSE
 //
-MJCalib::MJCalib() : fDataFlag(kIsUseRootData), fRuns(NULL)
+MJCalib::MJCalib() : fDataFlag(kIsUseRootData), fPixelCheck(kFALSE), fRuns(NULL)
 {
+  SetCheckedPixId();
 }
 
 Bool_t MJCalib::CheckEnvLocal()
 {
+
+    if (HasEnv("PixelCheck"))
+      SetPixelCheck();
+
+    if (HasEnv("CheckedPixId"))
+      SetCheckedPixId(GetEnv("CheckedPixId",fCheckedPixId));
+
     if (!HasEnv("DataType"))
         return kTRUE;
Index: trunk/MagicSoft/Mars/mjobs/MJCalib.h
===================================================================
--- trunk/MagicSoft/Mars/mjobs/MJCalib.h	(revision 6474)
+++ trunk/MagicSoft/Mars/mjobs/MJCalib.h	(revision 6475)
@@ -19,8 +19,15 @@
 
 private:
-    Byte_t fDataFlag;      // Bit-field to store the data type
+
+    static const Int_t fgCheckedPixId;  //! Default for fCheckedPixId
+
+    Byte_t fDataFlag;                    // Bit-field to store the data type
 
 protected:
-    MRunIter *fRuns;          // Data files, only used for test applications, default is sequence files!
+
+    Bool_t fPixelCheck;                  // Check a test pixel?
+    Int_t  fCheckedPixId;                // ID of checked pixel
+
+    MRunIter *fRuns;                     // Data files, only used for test applications, default is sequence files!
 
     Bool_t CheckEnvLocal();
@@ -30,6 +37,4 @@
 
     void SetInput(MRunIter *iter) { fRuns = iter; }
-
-    Byte_t GetDataFlag() const { return fDataFlag; }
 
     Bool_t IsUseRawData()  const { return fDataFlag==kIsUseRawData;  }
@@ -43,4 +48,7 @@
     void SetDataType(DataType_t type) { fDataFlag=type; }
   
+    void SetPixelCheck  ( const Bool_t b=kTRUE )         { fPixelCheck   = b; }
+    void SetCheckedPixId( const Int_t i=fgCheckedPixId ) { fCheckedPixId = i; }
+
     ClassDef(MJCalib, 0) // Base class for calibration jobs
 };
